RsaKey class abstract

Base class for RSA keys

Inheritance
Implementers

Constructors

RsaKey()

Properties

hashCode → int
The hash code for this object.
no setterinherited
modulus → BigInt
The modulus value for the RSA key
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited