RsaPrivateKey class abstract

A RSA private key

Inheritance
Implemented types

Constructors

RsaPrivateKey({required BigInt privateExponent, required BigInt firstPrimeFactor, required BigInt secondPrimeFactor, required BigInt modulus})
factory

Properties

firstPrimeFactor → BigInt
The first prime factor
no setter
hashCode → int
The hash code for this object.
no setterinherited
modulus → BigInt
The modulus value for the RSA key
no setterinherited
privateExponent → BigInt
The private exponent value for the RSA private key
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondPrimeFactor → BigInt
The second prime factor
no setter

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
createSigner(Identifier algorithm) → Signer<PrivateKey>
Creates a Signer using this key and the specified algorithm.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited