OkpKey class abstract
Base class for Octet Key Pair (OKP) keys (RFC 8037), such as Ed25519.
Unlike RsaKey or EcKey, an OKP key is represented by a raw octet string (rawBytes) rather than big-endian integers.
- Inheritance
- Implementers
Constructors
- OkpKey()
Properties
- curve → Identifier
-
The cryptographic curve used with the key, e.g.
curves.ed25519.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- rawBytes → Uint8List
-
The raw key octet string (RFC 8037 2).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createEncrypter(
Identifier algorithm) → Encrypter< Key> -
Creates an Encrypter using this key and the specified algorithm
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited