OkpPublicKey class abstract
An Octet Key Pair (OKP) public key, e.g. an Ed25519 public key.
Constructors
- OkpPublicKey({required Uint8List rawBytes, required Identifier curve})
-
factory
Properties
- curve → Identifier
-
The cryptographic curve used with the key, e.g.
curves.ed25519.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- rawBytes → Uint8List
-
The raw key octet string (RFC 8037 2).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createEncrypter(
Identifier algorithm) → Encrypter< Key> -
Creates an Encrypter using this key and the specified algorithm
inherited
-
createVerifier(
Identifier algorithm) → Verifier< PublicKey> -
Creates a signature Verifier using this key and the specified algorithm
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited